IntegerFormat

Enum IntegerFormat 

pub enum IntegerFormat {
    AlwaysDecimal,
    AlwaysHex,
    HexWhenOver(u64),
}

Variants



AlwaysDecimal

Always render integers as decimal.



AlwaysHex

Always render integers as hexadecimal. Note that negative numbers will still be rendered as decimal.



HexWhenOver(u64)

Render integers as hexadecimal when they are over a certain size.

Implementations

Source

impl IntegerFormat

pub fn format(&self, value: u64) -> String